from fastapi import FastAPI, Request
import requests
import asyncio
import toml

app = FastAPI()
queue = asyncio.Queue()
config = toml.load('config.toml')

@app.post("/send_alert")
async def send_alert(request: Request, webhook_url: str):

    webhook_url = config['webhooks'][webhook_url]
    if not webhook_url:
        return {"message": "Url not exist"}
    alert_info = await request.json()
    await queue.put((webhook_url, alert_info))
    return {"message": "Alert sent to asyncio task queue."}

async def send_alert_task():
    while True:
        webhook_url, alert_info = await queue.get()
        headers = {"Content-Type": "application/json"}
        response = requests.post(webhook_url, headers=headers, json=alert_info)
        queue.task_done()


async def start_send_alert_tasks():
    tasks = []
    for i in range(10):
        task = asyncio.create_task(send_alert_task())
        tasks.append(task)
    await asyncio.gather(*tasks)

@app.on_event("startup")
async def startup_event():
    asyncio.create_task(start_send_alert_tasks())

@app.on_event("shutdown")
async def shutdown_event():
    await queue.join()
